all_licenses

Function all_licenses 

pub fn all_licenses() -> Vec<GString>
Returns a list of known license references (in form of URIs). This is useful for UIs to build a list of available licenses for tagging purposes (e.g. to tag an audio track appropriately in a video or audio editor, or an image in a camera application).

Returns

NULL-terminated array of license strings. Free with g_strfreev() when no longer needed.